preprocess

package
v0.0.0-...-6a2e7b8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 3, 2022 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Convolution

func Convolution(signal *model.Signal[Point], d int) *model.Signal[Point]

Convolution accepts a signal and modifies it by performing convolutions on the signal.

Types

type Point

type Point struct {
	X, Y, C int
}

func (*Point) Adj

func (p *Point) Adj(d int) []Point

type Positional

type Positional interface {
	Adj(int) []Point
	comparable
}

A Positional is an interface for types which are positionally relative to one another. This interface is necessary to perform a convolution on the indexing type of the Signal. Neighbor should return an integer

Jump to