Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Positional ¶
type Positional interface {
Adj(int) []Point
comparable
}
A Positional is an interface for types which are positionally relative to one another. This interface is necessary to perform a convolution on the indexing type of the Signal. Neighbor should return an integer
Click to show internal directories.
Click to hide internal directories.